"{ Package: 'stx:goodies/sunit' }"

TestCase subclass:#SUnitTest
	instanceVariableNames:'hasRun hasSetup hasRanOnce'
	classVariableNames:''
	poolDictionaries:''
	category:'SUnit-Tests'
!

!SUnitTest class methodsFor:'documentation'!

description
    ^ 'Tests SUnit itself
Two tests should fail.'
! !

!SUnitTest class methodsFor:'testing'!

shouldInheritSelectors
	"answer true to inherit selectors from superclasses"

	^false
! !

!SUnitTest methodsFor:'accessing'!

hasRun
	^hasRun
!

hasSetup
	^hasSetup
! !

!SUnitTest methodsFor:'private'!

assertForTestResult: aResult runCount: aRunCount passed: aPassedCount failed: aFailureCount errors: anErrorCount

	self
		assert: aResult runCount = aRunCount;
		assert: aResult passedCount = aPassedCount;
		assert: aResult failureCount = aFailureCount;
		assert: aResult errorCount = anErrorCount
!

error
	3 zork

    "Modified: / 21.6.2000 / 10:22:18 / Sames"
!

fail
        "force a failure"
        self assert: false
!

noop
!

setRun
	hasRun := true
! !

!SUnitTest methodsFor:'running'!

setUp
	hasSetup := true
! !

!SUnitTest methodsFor:'testing'!

testAssert
	self assert: true.
	self deny: false
!

testDebugUI
	"This should break"
	3 zork

    "Modified: / 21.6.2000 / 10:22:50 / Sames"
!

testDefects
	| result suite error failure |
	suite := TestSuite new.
	suite addTest: (error := self class selector: #error).
	suite addTest: (failure := self class selector: #fail).
	result := suite run.
	self assert: result defects asArray = (Array with: error with: failure).
	self
		assertForTestResult: result
		runCount: 2
		passed: 0
		failed: 1
		errors: 1
!

testDialectLocalizedException
	self should: [TestResult signalFailureWith: 'Foo'] raise: TestResult failure.
	self should: [TestResult signalErrorWith: 'Foo'] raise: TestResult error.
	self shouldnt: [TestResult signalErrorWith: 'Foo'] raise: TestResult failure.

    "Modified: / 21.6.2000 / 10:23:20 / Sames"
!

testError
	| case result |
	case := self class selector: #error.
	result := case run.
	self
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 0
		errors: 1
!

testException
	self should: [self error: 'foo'] raise: TestResult error

    "Modified: / 21.6.2000 / 10:23:39 / Sames"
!

testFail
	| case result |
	case := self class selector: #fail.
	result := case run.
	self
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 1
		errors: 0
!

testFailureDebugUI
	"This should fail !!"
	self fail
!

testIsNotRerunOnDebug
	| case |
	case := self class selector: #testRanOnlyOnce.
	case run.
	case debug
!

testRan
	| case |
	case := self class selector: #setRun.
	case run.
	self assert: case hasSetup.
	self assert: case hasRun
!

testRanOnlyOnce
	self assert: hasRanOnce ~= true.
	hasRanOnce := true.
!

testResult
	| case result |
	case := self class selector: #noop.
	result := case run.
	self
		assertForTestResult: result
		runCount: 1
		passed: 1
		failed: 0
		errors: 0
!

testRunning
	(SUnitDelay forSeconds: 2) wait

    "Modified: / 21.6.2000 / 10:24:41 / Sames"
!

testShould
	self should: [true].
	self shouldnt: [false]
!

testSuite
	| suite result |
	suite := TestSuite new.
	suite addTest: (self class selector: #noop).
	suite addTest: (self class selector: #fail).
	suite addTest: (self class selector: #error).
	result := suite run.
	self
		assertForTestResult: result
		runCount: 3
		passed: 1
		failed: 1
		errors: 1
! !

!SUnitTest class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/goodies/sunit/SUnitTest.st,v 1.8 2002-02-26 10:30:34 cg Exp $'
! !
